@@ -1,11 +1,19 @@
-import dash
-import dash_html_components as html
+##################################################################
+#
+# Copyright (c) 2021- Equinor ASA
+#
+# This source code is licensed under the MIT license found in the
+# LICENSE file in the root directory of this source tree.
+#
+##################################################################
+
+from dash import html, Dash
 import webviz_core_components
 
 
 def test_colorscale(dash_duo):
 
-    app = dash.Dash(__name__)
+    app = Dash(__name__)
 
     app.layout = html.Div(
         [
