@@ -1,10 +1,16 @@
 from .ColorScales import ColorScales
+from .Menu import Menu
+from .Overlay import Overlay
+from .ScrollArea import ScrollArea
 from .Select import Select
 from .SmartNodeSelector import SmartNodeSelector
 from .WebvizPluginPlaceholder import WebvizPluginPlaceholder
 
 __all__ = [
     "ColorScales",
+    "Menu",
+    "Overlay",
+    "ScrollArea",
     "Select",
     "SmartNodeSelector",
     "WebvizPluginPlaceholder"
